==> nextcloud-11.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/lb.js <==
OC.L10N.register(
    "activity",
    {
    ", " : ", ",
    "This stream will show events like additions, changes & shares" : "Dëse Floss weist Evenementer wéi dobäigesaten, geännert a gedeelte Fichieren un",
    "There are no events for this filter" : "Et gi keng Evenenementer fir dëse Filter",
    "Today" : "Haut",
    "Activity" : "Aktivitéit",
    "Personal activity feed for %s" : "Perséinlechen Aktivitéite-Feed fir %s",
    "Your feed URL is invalid" : "D'Feed-Adress ass ongëlteg",
    "Your settings have been updated." : "Deng Astellunge goufen aktualiséiert.",
    "Mail" : "Mail",
    "Stream" : "Floss",
    "\"remote user\"" : "\"Remote-Benotzer\"",
    "Activity notification" : "Aktivitéits-Notifikatiounen",
    "All Activities" : "All Aktivitéiten",
    "Activities by you" : "Aktivitéite vun dir",
    "Activities by others" : "Aktivitéite vun anere Leit",
    "%s and %s" : "%s an %s",
    "Hello %s," : "Hallo %s,",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* an %n méi","* an %n méi"],
    "Notify about your own actions via email" : "Iwwer eegene Aktiounen iwwer E-Mail informéieren",
    "You need to set up your email address before you can receive notification emails." : "Du muss deng E-Mail-Adress konfiguréieren ier s de Notifikatiouns-Maile kanns emfänken.",
    "Send emails:" : "Emaile schécken:",
    "Hourly" : "All Stonn",
    "Daily" : "All Dag",
    "Weekly" : "All Woch",
    "Activity feed" : "Aktivitéits-Feed",
    "Enable RSS feed" : "RSS-Feed aktivéieren",
    "No activity yet" : "Bis elo keng Aktivitéit",
    "No more events to load" : "Keng weider Evenementer fir ze lueden",
    "Files" : "Fichieren"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-13.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/lb.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "Aktivitéiten",
    "No activity yet" : "Bis elo keng Aktivitéit",
    "Load more activities" : "Lued méi Aktivitéiten",
    "Copied!" : "Kopéiert!",
    "Not supported!" : "Nët ennerstëtzt!",
    "Press ⌘-C to copy." : "Dréck ⌘-C fir ze kopéieren.",
    "Press Ctrl-C to copy." : "Dréck CTRL-C fir ze kopéieren.",
    "{name} (invisible)" : "[Numm][verstoppt]",
    "{name} (restricted)" : "[Numm][verbueden]",
    "in {path}" : "am [Pad]",
    "This stream will show events like additions, changes & shares" : "Dëse Floss weist Evenementer wéi dobäigesaten, geännert a gedeelte Fichieren un",
    "There are no events for this filter" : "Et gi keng Evenenementer fir dëse Filter",
    "Today" : "Haut",
    "Yesterday" : "Gëschter",
    "Personal activity feed for %s" : "Perséinlechen Aktivitéite-Feed fir %s",
    "Your feed URL is invalid" : "D'Feed-Adress ass ongëlteg",
    "Your settings have been updated." : "Deng Astellunge goufen aktualiséiert.",
    "Mail" : "Mail",
    "Stream" : "Floss",
    "All activities" : "All Aktivitéiten",
    "By others" : "Vun aneren",
    "By you" : "Vun dir",
    "\"remote user\"" : "\"Remote-Benotzer\"",
    "Hello %s," : "Hallo %s,",
    "There was some activity at %s" : "Et goufen Ännerungen bei ¦%s",
    "Activity notification" : "Aktivitéits-Notifikatiounen",
    ", " : ", ",
    "%s and %s" : "%s an %s",
    "Activity" : "Aktivitéit",
    "Activity feed" : "Aktivitéits-Feed",
    "List your own actions in the stream" : "Weis är aner Aktivitéiten am Floss",
    "Notify about your own actions via email" : "Iwwer eegene Aktiounen iwwer E-Mail informéieren",
    "You need to set up your email address before you can receive notification emails." : "Du muss deng E-Mail-Adress konfiguréieren ier s de Notifikatiouns-Maile kanns emfänken.",
    "Send emails:" : "Emaile schécken:",
    "Hourly" : "All Stonn",
    "Daily" : "All Dag",
    "Weekly" : "All Woch",
    "Settings" : "Astellungen",
    "Enable RSS feed" : "RSS-Feed aktivéieren",
    "No more events to load" : "Keng weider Evenementer fir ze lueden",
    "Files" : "Fichieren"
},
"nplurals=2; plural=(n != 1);");
